# Critique / Models of Good Data Visualization

---
## This Week

- Review common rules & mistakes.
- What makes a useful critique?
- Look at a lot of data viz examples.

---

## Reminder: Color

- Appropriate & consistent use of color for data type.
- Contrast & distinguishable palette.
- Cultural/contextual considerations.
- Accessibility: contrast, color vision deficiency, legibility

---

## Reminder: Data / Chart Integrity

- Data variation, not design variation.
- Maximize data-ink ratio.
- Remove all chart junk. (gridlines, shadows, 3d effects)
- Context: title, axes, units, important events.
- Alignment/Proximity: make comparisons easy & avoid misleading choices like changing axes between two otherwise identical graphs

---

## Critique

- What is the purpose of critique?
- Constructive Language
- Taking Critique

---

## Purpose of Critique

You are the expert on your data source, and it can be challenging to look at things through the eyes of your audience.

Also it is likely that you've stared at variations of the same chart for an hour or more, easily overlooking small flaws.

Extra eyes will help you identify what people are actually taking away from your graphic:

- Highlight accessibility issues.
- Preempt confusion/accidentally misleading intended audience.
- Uncover unconscious biases.
- Consider alternative solutions.

---

## Giving Critique

**Be specific.** If your first impulse is "I like it/I don't like it" go deeper and connect with why. Does it violate principles? Does a color choice stress your eye?

**Give your interpretation.** What do you take away from the graphic as-is. Where is your eye drawn? Check your understanding against intention.

**Balance positives and negatives.** Find things that *are working* and incorporate those into feedback as well. It's easier on recipient but also important so that they don't get removed in revision.

**Offer alternatives.** What could be done differently?

- *"I like..."* - point out what works.
- *"I wish..."* - frame negative feedback as ways that it could improve for audience.
- *"What if..."* - new ideas and alternatives to consider.

**Be respectful.** Be mindful of your tone and word choice.

---

## What to Avoid (Giving Critique)

**Comments on creator.** "You always...", "What were you thinking?", etc.  **Stay focused on the work.**

**Bike-shedding.** Suggesting *arbitrary* changes based on your preferences. "If I made this, I'd have chosen green."

---

## What to Look For

### Expressiveness
- Prioritizes important information / Avoids false inferences
- Consistent visual mappings (e.g., respect color mappings)
- Make encodings meaningful rather than arbitrary

### Effectiveness
- Facilitates accurate decoding / Minimizes cognitive overhead
- Highlight elements of primary interest

### Grouping / Sorting

### Non-Data Elements
- Descriptive: Title, Label, Caption, Data Source, Annotations
- Reference: Gridlines, Legend

---

## Taking Critique

**Listen without defensiveness.** Do not interrupt initial feedback to point out "oh what that meant is ___", doing so will lead to missing important first impressions.

**Separate yourself from the work.** Remember the context you are doing this in, your peer is giving you their time to improve your work.

**Ask clarifying questions.** If you do not understand why their interpretation is what it is, ask! Take the opportunity to learn more about what a new viewer will see.

**Look for patterns.** Feedback may be unique or contradictory. Focus on trends in the feedback that point to common issues.

---

## What to Avoid (Taking Critique)

**Convincing.** If someone misunderstood your viz, others will too. There's nothing to be gained by convincing them they actually do understand it.

**Assuming all feedback is correct.** If you disagree with a piece of feedback, it is OK to thank the person for it and not incorporate that into your changes if you feel strongly it was off base. There's generally no need to debate them on the spot however.

---

## Suggested Peer Critique Process

1) Share work with no commentary.  Give everyone in the group a chance to form initial opinions.  As a reviewer, jot down a few notes.

2) Author can now provide explanation of audience/intent. Keep this short & avoid explaining specifics of any graphic. I recommend doing this after the initial impression to avoid coloring people's first take. If author has 1-2 specific questions they could be introduced at this time.

3) Start with some positive feedback. What is working well.

4) Offer constructive criticisms and other suggestions for improvements and things to try.  Author should mostly listen at this point, take notes, avoid the urge to respond to each piece of feedback as offered.

5) Author can now ask clarifying questions and respond as appropriate.
    - "When you said you didn't understand X, did looking at the next chart help? If I reorder those would it have helped?""
    - "Does anyone have "

6) Consolidate and summarize feedback and next steps.  "OK I think I'll take a pass at a standard scatterplot here since the bubble chart was confusing people."

---

## Example 1

TODO: A Famous One

---

## Example 2:

TODO: Something from Amy

---

## Example

Solving a unique problem

---

## Example  

Solving a unique problem

---

## Example 3: 

TODO: gathering

---

## Example 4:

TODO: gathering

---

## Example 5:

TODO: gathering

---

## Example 6:

TODO: gathering

---

## Readings & Sources

- [Critiquing data visualizations: A discussion on channeling empathy and productivity]( https://www.tableau.com/blog/critiquing-data-visualizations-channel-empathy-and-be-productive)
- TODO: https://policyviz.com/2020/07/19/critiquing-a-data-visualization-critique/
